# -*- coding: utf-8 -*-
"""
Author: Bernhard Scheirle
"""
from __future__ import unicode_literals

import os

from pelican.contents import Content
from pelican.utils import slugify

from . import avatars


class Comment(Content):
    mandatory_properties = ('author', 'date')
    default_template = 'None'

    allowed_statuses = ('published'),
    default_status = 'published'
    article = None

    def __init__(self, content, metadata, settings, source_path, context):
        # Strip the path off the full filename.
        name = os.path.split(source_path)[1]

        if not hasattr(self, 'slug'):
            # compute the slug before initializing the base Content object, so
            # it doesn't get set there
            # This is required because we need a slug containing the file
            # extension.
            self.slug = slugify(name, settings.get('SLUG_SUBSTITUTIONS', ()))

        super(Comment, self).__init__(content, metadata, settings, source_path,
                                      context)

        self.replies = []

        # Strip the extension from the filename.
        name = os.path.splitext(name)[0]
        self.avatar = avatars.getAvatarPath(name, metadata)
        self.title = "Posted by:  {}".format(metadata['author'])

    def addReply(self, comment):
        self.replies.append(comment)

    def getReply(self, slug):
        for reply in self.replies:
            if reply.slug == slug:
                return reply
            else:
                deepReply = reply.getReply(slug)
                if deepReply is not None:
                    return deepReply
        return None

    def __lt__(self, other):
        return self.date < other.date

    def sortReplies(self):
        for r in self.replies:
            r.sortReplies()
        self.replies = sorted(self.replies)

    def countReplies(self):
        amount = 0
        for r in self.replies:
            amount += r.countReplies()
        return amount + len(self.replies)



#! python3.6
"""
Export Comments from BLogger XML

Takes in a Blogger export XML file and spits out each comment in a separate
file, such that can be used with the [Pelican Comment System]
(https://bernhard.scheirle.de/posts/2014/March/29/static-comments-via-email/).

May be simple to extend to export posts as well.

For a more detailed description, read my blog post at
    http://blog.minchin.ca/2016/12/blogger-comments-exported.html

Author: Wm. Minchin -- minchinweb@gmail.com
License: MIT
Changes:

 - 2016.12.29 -- initial release
 - 2017.01.10 -- clean-up for addition in Pelican Comment System repo
"""

from pathlib import Path

import untangle

###############################################################################
# Constants                                                                   #
###############################################################################

BLOGGER_EXPORT = r'c:\tmp\blog.xml'
COMMENTS_DIR = 'comments'
COMMENT_EXT = '.md'
AUTHORS_FILENAME = 'authors.txt'

###############################################################################
# Main Code Body                                                              #
###############################################################################

authors_and_pics = []


def main():
    obj = untangle.parse(BLOGGER_EXPORT)

    templates = 0
    posts = 0
    comments = 0
    settings = 0
    others = 0

    for entry in obj.feed.entry:
        try:
            full_type = entry.category['term']
        except TypeError:
            # if a post is under multiple categories
            for my_category in entry.category:
                full_type = my_category['term']
                # str.find() uses a return of `-1` to denote failure
                if full_type.find('#') != -1:
                    break
            else:
                others += 1

        simple_type = full_type[full_type.find('#')+1:]

        if 'settings' == simple_type:
            settings += 1
        elif 'post' == simple_type:
            posts += 1
            # process posts here
        elif 'comment' == simple_type:
            comments += 1
            process_comment(entry, obj)
        elif 'template' == simple_type:
            templates += 1
        else:
            others += 1

    export_authors()

    print('''
            {} template
            {} posts (including drafts)
            {} comments
            {} settings
            {} other entries'''.format(templates,
                                       posts,
                                       comments,
                                       settings,
                                       others))


def process_comment(entry, obj):
    # e.g. "tag:blogger.com,1999:blog-26967745.post-4115122471434984978"
    comment_id = entry.id.cdata
    # in ISO 8601 format, usable as is
    comment_published = entry.published.cdata
    comment_body = entry.content.cdata
    comment_post_id = entry.thr_in_reply_to['ref']
    comment_author = entry.author.name.cdata
    comment_author_pic = entry.author.gd_image['src']
    comment_author_email = entry.author.email.cdata

    # add author and pic to global list
    global authors_and_pics
    authors_and_pics.append((comment_author, comment_author_pic))

    # use this for a filename for the comment
    # e.g. "4115122471434984978"
    comment_short_id = comment_id[comment_id.find('post-')+5:]

    comment_text = "date: {}\nauthor: {}\nemail: {}\n\n{}\n"\
                        .format(comment_published,
                                comment_author,
                                comment_author_email,
                                comment_body)

    # article
    for entry in obj.feed.entry:
        entry_id = entry.id.cdata
        if entry_id == comment_post_id:
            article_entry = entry
            break
    else:
        print("No matching article for comment", comment_id, comment_post_id)
        # don't process comment further
        return

    # article slug
    for link in article_entry.link:
        if link['rel'] == 'alternate':
            article_link = link['href']
            break
    else:
        article_title = article_entry.title.cdata
        print('Could not find slug for', article_title)
        article_link = article_title.lower().replace(' ', '-')

    article_slug = article_link[article_link.rfind('/')+1:
                                                    article_link.find('.html')]

    comment_filename = Path(COMMENTS_DIR).resolve()
    # folder; if it doesn't exist, create it
    comment_filename = comment_filename / article_slug
    comment_filename.mkdir(parents=True, exist_ok=True)
    # write the comment file
    comment_filename = comment_filename / (comment_short_id + COMMENT_EXT)
    comment_filename.write_text(comment_text)


def export_authors():
    to_export = set(authors_and_pics)
    to_export = list(to_export)
    to_export.sort()

    str_export = ''
    for i in to_export:
        str_export += (i[0] + '\t\t' + i[1] + '\n')

    authors_filename = Path(COMMENTS_DIR).resolve() / AUTHORS_FILENAME
    authors_filename.write_text(str_export)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
identicon.py
identicon python implementation.
by Shin Adachi <shn@glucose.jp>

= usage =

== commandline ==
>>> python identicon.py [code]

== python ==
>>> import identicon
>>> identicon.render_identicon(code, size)

Return a PIL Image class instance which have generated identicon image.
```size``` specifies `patch size`. Generated image size is 3 * ```size```.
"""
# g
# PIL Modules
from PIL import Image, ImageColor, ImageDraw, ImagePath

__all__ = ['render_identicon', 'IdenticonRendererBase']


class Matrix2D(list):

    """Matrix for Patch rotation"""

    def __init__(self, initial=[0.] * 9):
        assert isinstance(initial, list) and len(initial) == 9
        list.__init__(self, initial)

    def clear(self):
        for i in xrange(9):
            self[i] = 0.

    def set_identity(self):
        self.clear()
        for i in xrange(3):
            self[i] = 1.

    def __str__(self):
        return '[%s]' % ', '.join('%3.2f' % v for v in self)

    def __mul__(self, other):
        r = []
        if isinstance(other, Matrix2D):
            for y in range(3):
                for x in range(3):
                    v = 0.0
                    for i in range(3):
                        v += (self[i * 3 + x] * other[y * 3 + i])
                    r.append(v)
        else:
            raise NotImplementedError
        return Matrix2D(r)

    def for_PIL(self):
        return self[0:6]

    @classmethod
    def translate(kls, x, y):
        return kls([1.0, 0.0, float(x),
                    0.0, 1.0, float(y),
                    0.0, 0.0, 1.0])

    @classmethod
    def scale(kls, x, y):
        return kls([float(x), 0.0, 0.0,
                    0.0, float(y), 0.0,
                    0.0, 0.0, 1.0])

    """
    # need `import math`
    @classmethod
    def rotate(kls, theta, pivot=None):
        c = math.cos(theta)
        s = math.sin(theta)

        matR = kls([c, -s, 0., s, c, 0., 0., 0., 1.])
        if not pivot:
            return matR
        return kls.translate(-pivot[0], -pivot[1]) * matR *
            kls.translate(*pivot)
    """

    @classmethod
    def rotateSquare(kls, theta, pivot=None):
        theta = theta % 4
        c = [1., 0., -1., 0.][theta]
        s = [0., 1., 0., -1.][theta]

        matR = kls([c, -s, 0., s, c, 0., 0., 0., 1.])
        if not pivot:
            return matR
        return kls.translate(-pivot[0], -pivot[1]) * matR * \
            kls.translate(*pivot)


class IdenticonRendererBase(object):
    PATH_SET = []

    def __init__(self, code):
        """
        @param code code for icon
        """
        if not isinstance(code, int):
            code = int(code)
        self.code = code

    def render(self, size):
        """
        render identicon to PIL.Image

        @param size identicon patchsize. (image size is 3 * [size])
        @return PIL.Image
        """

        # decode the code
        middle, corner, side, foreColor, backColor = self.decode(self.code)
        size = int(size)
        # make image
        image = Image.new("RGB", (size * 3, size * 3))
        draw = ImageDraw.Draw(image)

        # fill background
        draw.rectangle((0, 0, image.size[0], image.size[1]), fill=0)

        kwds = {
            'draw': draw,
            'size': size,
            'foreColor': foreColor,
            'backColor': backColor}
        # middle patch
        self.drawPatch((1, 1), middle[2], middle[1], middle[0], **kwds)

        # side patch
        kwds['type'] = side[0]
        for i in range(4):
            pos = [(1, 0), (2, 1), (1, 2), (0, 1)][i]
            self.drawPatch(pos, side[2] + 1 + i, side[1], **kwds)

        # corner patch
        kwds['type'] = corner[0]
        for i in range(4):
            pos = [(0, 0), (2, 0), (2, 2), (0, 2)][i]
            self.drawPatch(pos, corner[2] + 1 + i, corner[1], **kwds)

        return image

    def drawPatch(self, pos, turn, invert, type, draw, size, foreColor,
                  backColor):
        """
        @param size patch size
        """
        path = self.PATH_SET[type]
        if not path:
            # blank patch
            invert = not invert
            path = [(0., 0.), (1., 0.), (1., 1.), (0., 1.), (0., 0.)]
        patch = ImagePath.Path(path)
        if invert:
            foreColor, backColor = backColor, foreColor

        mat = Matrix2D.rotateSquare(turn, pivot=(0.5, 0.5)) *\
            Matrix2D.translate(*pos) *\
            Matrix2D.scale(size, size)

        patch.transform(mat.for_PIL())
        draw.rectangle((pos[0] * size, pos[1] * size, (pos[0] + 1) * size,
                        (pos[1] + 1) * size), fill=backColor)
        draw.polygon(patch, fill=foreColor, outline=foreColor)

    # virtual functions
    def decode(self, code):
        raise NotImplementedError


class DonRenderer(IdenticonRendererBase):

    """
    Don Park's implementation of identicon
    see : http://www.docuverse.com/blog/donpark/2007/01/19/identicon-updated-and-source-released
    """

    PATH_SET = [
        [(0, 0), (4, 0), (4, 4), (0, 4)],   # 0
        [(0, 0), (4, 0), (0, 4)],
        [(2, 0), (4, 4), (0, 4)],
        [(0, 0), (2, 0), (2, 4), (0, 4)],
        [(2, 0), (4, 2), (2, 4), (0, 2)],   # 4
        [(0, 0), (4, 2), (4, 4), (2, 4)],
        [(2, 0), (4, 4), (2, 4), (3, 2), (1, 2), (2, 4), (0, 4)],
        [(0, 0), (4, 2), (2, 4)],
        [(1, 1), (3, 1), (3, 3), (1, 3)],   # 8
        [(2, 0), (4, 0), (0, 4), (0, 2), (2, 2)],
        [(0, 0), (2, 0), (2, 2), (0, 2)],
        [(0, 2), (4, 2), (2, 4)],
        [(2, 2), (4, 4), (0, 4)],
        [(2, 0), (2, 2), (0, 2)],
        [(0, 0), (2, 0), (0, 2)],
        []]                                 # 15
    MIDDLE_PATCH_SET = [0, 4, 8, 15]

    # modify path set
    for idx in range(len(PATH_SET)):
        if PATH_SET[idx]:
            p = map(lambda vec: (vec[0] / 4.0, vec[1] / 4.0), PATH_SET[idx])
            p = list(p)
            PATH_SET[idx] = p + p[:1]

    def decode(self, code):
        # decode the code
        middleType = self.MIDDLE_PATCH_SET[code & 0x03]
        middleInvert = (code >> 2) & 0x01
        cornerType = (code >> 3) & 0x0F
        cornerInvert = (code >> 7) & 0x01
        cornerTurn = (code >> 8) & 0x03
        sideType = (code >> 10) & 0x0F
        sideInvert = (code >> 14) & 0x01
        sideTurn = (code >> 15) & 0x03
        blue = (code >> 16) & 0x1F
        green = (code >> 21) & 0x1F
        red = (code >> 27) & 0x1F

        foreColor = (red << 3, green << 3, blue << 3)

        return (middleType, middleInvert, 0),\
               (cornerType, cornerInvert, cornerTurn),\
               (sideType, sideInvert, sideTurn),\
            foreColor, ImageColor.getrgb('white')


def render_identicon(code, size, renderer=None):
    if not renderer:
        renderer = DonRenderer
    return renderer(code).render(size)


if __name__ == '__main__':
    import sys

    if len(sys.argv) < 2:
        print('usage: python identicon.py [CODE]....')
        raise SystemExit

    for code in sys.argv[1:]:
        if code.startswith('0x') or code.startswith('0X'):
            code = int(code[2:], 16)
        elif code.startswith('0'):
            code = int(code[1:], 8)
        else:
            code = int(code)

        icon = render_identicon(code, 24)
        icon.save('%08x.png' % code, 'PNG')



# -*- coding: utf-8 -*-
"""
Pelican Static Comment System
======================

A Pelican plugin, which allows you to add static comments to your articles.

Creator: Bernhard Scheirle
Maintainer: William Minchin
"""
from __future__ import unicode_literals

import copy
import logging
import os

logger = logging.getLogger(__name__)

from itertools import chain

from pelican import signals
from pelican.readers import Readers
from pelican.writers import Writer

from . import avatars
from .comment import Comment

# fmt: off
__version__ = "2.0.0"
__title__ = "minchin.pelican.plugins.static-comments"
__description__ = "A Pelican plugin, which allows you to add static comments to your articles."
__author__ = "William Minchin"
__email__ = "w_minchin@hotmail.com"
__url__ = "https://github.com/MinchinWeb/minchin.pelican.plugins.static-comments"
__license__ = "GPLv3+"
# fmt: on

_all_comments = []
_pelican_writer = None
_pelican_obj = None


def setdefault(pelican, settings):
    from pelican.settings import DEFAULT_CONFIG

    for key, value in settings:
        DEFAULT_CONFIG.setdefault(key, value)

    if not pelican:
        return

    for key, value in settings:
        pelican.settings.setdefault(key, value)


def pelican_initialized(pelican):
    from pelican.settings import DEFAULT_CONFIG

    settings = [
        ("PELICAN_COMMENT_SYSTEM", False),
        ("PELICAN_COMMENT_SYSTEM_DIR", "comments"),
        ("PELICAN_COMMENT_SYSTEM_IDENTICON_OUTPUT_PATH", "images/identicon"),
        ("PELICAN_COMMENT_SYSTEM_IDENTICON_DATA", ()),
        ("PELICAN_COMMENT_SYSTEM_IDENTICON_SIZE", 72),
        ("PELICAN_COMMENT_SYSTEM_AUTHORS", {}),
        ("PELICAN_COMMENT_SYSTEM_FEED", os.path.join("feeds", "comment.%s.atom.xml")),
        (
            "PELICAN_COMMENT_SYSTEM_FEED_ALL",
            os.path.join("feeds", "comments.all.atom.xml"),
        ),
        ("COMMENT_URL", "#comment-{slug}"),
    ]

    setdefault(pelican, settings)

    DEFAULT_CONFIG["PAGE_EXCLUDES"].append(DEFAULT_CONFIG["PELICAN_COMMENT_SYSTEM_DIR"])
    DEFAULT_CONFIG["ARTICLE_EXCLUDES"].append(
        DEFAULT_CONFIG["PELICAN_COMMENT_SYSTEM_DIR"]
    )
    pelican.settings["PAGE_EXCLUDES"].append(
        pelican.settings["PELICAN_COMMENT_SYSTEM_DIR"]
    )
    pelican.settings["ARTICLE_EXCLUDES"].append(
        pelican.settings["PELICAN_COMMENT_SYSTEM_DIR"]
    )

    global _pelican_obj
    _pelican_obj = pelican


def initialize(article_generator):
    avatars.init(
        article_generator.settings["OUTPUT_PATH"],
        article_generator.settings["PELICAN_COMMENT_SYSTEM_IDENTICON_OUTPUT_PATH"],
        article_generator.settings["PELICAN_COMMENT_SYSTEM_IDENTICON_DATA"],
        article_generator.settings["PELICAN_COMMENT_SYSTEM_IDENTICON_SIZE"] / 3,
        article_generator.settings["PELICAN_COMMENT_SYSTEM_AUTHORS"],
    )

    # Reset old states (autoreload mode)
    global _all_comments
    global _pelican_writer
    try:
        # Pelican 4.5.2 and newer
        # see https://github.com/getpelican/pelican/commit/afdf0fb3cf6cd376a6f241e2d5bbf99cf0e348c2
        _pelican_writer = _pelican_obj._get_writer()
    except AttributeError:
        _pelican_writer = _pelican_obj.get_writer()
    _all_comments = []


def warn_on_slug_collision(items):
    slugs = {}
    for comment in items:
        if comment.slug not in slugs:
            slugs[comment.slug] = [comment]
        else:
            slugs[comment.slug].append(comment)

    for slug, itemList in slugs.items():
        len_ = len(itemList)
        if len_ > 1:
            logger.warning("There are %s comments with the same slug: %s", len_, slug)
            for x in itemList:
                logger.warning("    %s", x.source_path)


def write_feed_all(gen, writer):
    if gen.settings["PELICAN_COMMENT_SYSTEM"] is not True:
        return
    if gen.settings["PELICAN_COMMENT_SYSTEM_FEED_ALL"] is None:
        return

    context = copy.copy(gen.context)
    context["SITENAME"] += " - All Comments"
    context["SITESUBTITLE"] = ""
    path = gen.settings["PELICAN_COMMENT_SYSTEM_FEED_ALL"]

    global _all_comments
    _all_comments = sorted(_all_comments)
    _all_comments.reverse()

    for com in _all_comments:
        com.title = com.article.title + " - " + com.title
        com.override_url = com.article.url + com.url

    writer.write_feed(_all_comments, context, path)


def write_feed(gen, items, context, slug):
    if gen.settings["PELICAN_COMMENT_SYSTEM_FEED"] is None:
        return

    path = gen.settings["PELICAN_COMMENT_SYSTEM_FEED"] % slug
    _pelican_writer.write_feed(items, context, path)


def process_comments(article_generator):
    for article in article_generator.articles:
        add_static_comments(article_generator, article)


def mirror_to_translations(article):
    for translation in article.translations:
        translation.comments_count = article.comments_count
        translation.comments = article.comments


def add_static_comments(gen, content):
    if gen.settings["PELICAN_COMMENT_SYSTEM"] is not True:
        return

    global _all_comments

    content.comments_count = 0
    content.comments = []
    mirror_to_translations(content)

    # Modify the local context, so we get proper values for the feed
    context = copy.copy(gen.context)
    context["SITEURL"] += "/" + content.url
    context["SITENAME"] += " - Comments: " + content.title
    context["SITESUBTITLE"] = ""

    folder = os.path.join(
        gen.settings["PATH"], gen.settings["PELICAN_COMMENT_SYSTEM_DIR"], content.slug
    )

    if not os.path.isdir(folder):
        logger.debug("No comments found for: %s", content.slug)
        write_feed(gen, [], context, content.slug)
        return

    reader = Readers(gen.settings)
    comments = []
    replies = []

    for file in os.listdir(folder):
        name, extension = os.path.splitext(file)
        if extension[1:].lower() in reader.extensions:
            com = reader.read_file(
                base_path=folder, path=file, content_class=Comment, context=context
            )

            com.article = content
            _all_comments.append(com)

            if hasattr(com, "replyto"):
                replies.append(com)
            else:
                comments.append(com)

    feed_items = sorted(comments + replies)
    feed_items.reverse()
    warn_on_slug_collision(feed_items)

    write_feed(gen, feed_items, context, content.slug)

    # TODO: Fix this O(n²) loop
    for reply in replies:
        found_parent = False
        for comment in chain(comments, replies):
            if comment.slug == reply.replyto:
                comment.addReply(reply)
                found_parent = True
                break
        if not found_parent:
            logger.warning(
                'Comment "%s/%s" is a reply to non-existent '
                'comment "%s". Make sure the replyto attribute is '
                "set correctly.",
                content.slug,
                reply.slug,
                reply.replyto,
            )

    count = 0
    for comment in comments:
        comment.sortReplies()
        count += comment.countReplies()

    comments = sorted(comments)

    content.comments_count = len(comments) + count
    content.comments = comments
    mirror_to_translations(content)


def writeIdenticonsToDisk(gen, writer):
    avatars.generateAndSaveMissingAvatars()


def pelican_finalized(pelican):
    if pelican.settings["PELICAN_COMMENT_SYSTEM"] is not True:
        return
    global _all_comments
    print("Processed %s comment(s)" % len(_all_comments))


def register():
    signals.initialized.connect(pelican_initialized)
    signals.article_generator_init.connect(initialize)
    signals.article_generator_finalized.connect(process_comments)
    signals.article_writer_finalized.connect(writeIdenticonsToDisk)
    signals.article_writer_finalized.connect(write_feed_all)
    signals.finalized.connect(pelican_finalized)



# -*- coding: utf-8 -*-
"""
Author: Bernhard Scheirle
"""

from __future__ import unicode_literals

import hashlib
import logging
import os

logger = logging.getLogger(__name__)
_log = "pelican_comment_system: avatars: "
try:
    from .identicon import identicon
    _identiconImported = True
except ImportError as e:
    logger.warning(_log + "identicon deactivated: " + str(e))
    _identiconImported = False

# Global Variables
_identicon_save_path = None
_identicon_output_path = None
_identicon_data = None
_identicon_size = None
_initialized = False
_authors = None
_missingAvatars = []


def _ready():
    if not _initialized:
        logger.warning(_log + "Module not initialized. use init")
    if not _identicon_data:
        logger.debug(_log + "No identicon data set")
    return _identiconImported and _initialized and _identicon_data


def init(pelican_output_path, identicon_output_path, identicon_data,
         identicon_size, authors):
    global _identicon_save_path
    global _identicon_output_path
    global _identicon_data
    global _identicon_size
    global _initialized
    global _authors
    global _missingAvatars

    _identicon_save_path = os.path.join(pelican_output_path,
                                        identicon_output_path)
    _identicon_output_path = identicon_output_path
    _identicon_data = identicon_data
    _identicon_size = identicon_size
    _authors = authors
    _missingAvatars = []
    _initialized = True


def _createIdenticonOutputFolder():
    if not _ready():
        return

    if not os.path.exists(_identicon_save_path):
        os.makedirs(_identicon_save_path)


def getAvatarPath(comment_id, metadata):
    if not _ready():
        return ''

    md5 = hashlib.md5()
    author = tuple()
    for data in _identicon_data:
        if data in metadata:
            string = "{}".format(metadata[data])
            md5.update(string.encode('utf-8'))
            author += tuple([string])
        else:
            logger.warning(_log + data +
                           " is missing in comment: " + comment_id)

    if author in _authors:
        return _authors[author]

    global _missingAvatars

    code = md5.hexdigest()

    if code not in _missingAvatars:
        _missingAvatars.append(code)

    return os.path.join(_identicon_output_path, '%s.png' % code)


def generateAndSaveMissingAvatars():
    _createIdenticonOutputFolder()
    global _missingAvatars
    for code in _missingAvatars:
        avatar_path = '%s.png' % code
        avatar = identicon.render_identicon(int(code, 16), _identicon_size)
        avatar_save_path = os.path.join(_identicon_save_path, avatar_path)
        avatar.save(avatar_save_path, 'PNG')
    _missingAvatars = []



#!/usr/bin/env python

import codecs
import os
import re

import setuptools

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    # intentionally *not* adding an encoding option to open
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_meta(*meta_file_parts, meta_key):
    """
    Extract __*meta*__ from meta_file
    """
    meta_file = read(*meta_file_parts)
    meta_match = re.search(r"^__{}__ = ['\"]([^'\"]*)['\"]".format(meta_key),
                           meta_file, re.M)
    if meta_match:
        return meta_match.group(1)
    raise RuntimeError("Unable to find __{}__ string.".format(meta_key))


##############################################################################
#                          PACKAGE METADATA                                  #
##############################################################################
META_PATH = ['minchin', 'pelican', 'plugins', 'static_comments', '__init__.py']

NAME         = find_meta(*META_PATH, meta_key='title').lower()
VERSION      = find_meta(*META_PATH, meta_key='version')
URL          = find_meta(*META_PATH, meta_key='url')
SHORT_DESC   = find_meta(*META_PATH, meta_key='description')
LONG_DESC    = "\n\n".join(
    [
        read('README.rst')
        .replace("<docs/", "<" + URL + "/doc/")
        .replace("<./", "<" + URL + "/"),
        read('CHANGELOG.rst'),
    ]
)
AUTHOR       = find_meta(*META_PATH, meta_key='author')
AUTHOR_EMAIL = find_meta(*META_PATH, meta_key='email')
LICENSE      = find_meta(*META_PATH, meta_key='license')

# PACKAGES     = setuptools.find_packages(exclude="vendor_src")
# PACKAGES     = setuptools.find_namespace_packages()
PACKAGES     = setuptools.find_namespace_packages(include=['minchin.*'])
# PACKAGES     = setuptools.find_namespace_packages(include=['minchin.pelican.plugins.*'])
# PACKAGES     = [
#     'minchin.pelican.plugins.static_comments',
#     'minchin.pelican.plugins.static_comments.identicons',
# ]

INSTALL_REQUIRES = [
    'minchin.pelican.plugins.autoloader',
    'pelican >= 3.4',
    'pillow',
]

EXTRA_REQUIRES = {
    'build': [
        'minchin.releaser',
        'pip-tools',
    ],
    'docs': [
    ],
    'test': [
    ],
    'blogger': [
        "untangle",
    ]
}

# full list of Classifiers at
# https://pypi.python.org/pypi?%3Aaction=list_classifiers
CLASSIFIERS = [
    #   having an unknown classifier should keep PyPI from accepting the
    #   package as an upload
    # 'Private :: Do Not Upload',

    # 'Development Status :: 1 - Planning',
    # 'Development Status :: 2 - Pre-Alpha',
    # 'Development Status :: 3 - Alpha',
    # 'Development Status :: 4 - Beta',
    'Development Status :: 5 - Production/Stable',
    # 'Development Status :: 6 - Mature',
    # 'Development Status :: 7 - Inactive',

    # 'Programming Language :: Python :: 2',
    # 'Programming Language :: Python :: 2.6',
    # 'Programming Language :: Python :: 2.7',
    # 'Programming Language :: Python :: 2 :: Only',
    'Programming Language :: Python :: 3',
    # 'Programming Language :: Python :: 3.2',
    # 'Programming Language :: Python :: 3.3',
    # 'Programming Language :: Python :: 3.4',
    # 'Programming Language :: Python :: 3.5',
    # 'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    # 'Programming Language :: Python :: 3 :: Only',

    'Environment :: Console',
    'Framework :: Pelican :: Plugins',
    "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
    'Operating System :: OS Independent',
    "Topic :: Software Development :: Libraries :: Python Modules",
]
##############################################################################

if LICENSE in ['MIT License']:
    CLASSIFIERS += ['License :: OSI Approved :: {}'.format(LICENSE)]

# add 'all' key to EXTRA_REQUIRES
all_requires = []
for k, v in EXTRA_REQUIRES.items():
    all_requires.extend(v)
EXTRA_REQUIRES['all'] = all_requires


setuptools.setup(
    name=NAME,
    version=VERSION,
    url=URL,
    license=LICENSE,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    description=SHORT_DESC,
    long_description=LONG_DESC,
    long_description_content_type='text/x-rst',
    packages=PACKAGES,
    package_data={'': ['README.rst', 'CHANGELOG.rst', 'License.txt']},
    include_package_data=True,
    install_requires=INSTALL_REQUIRES,
    extras_require=EXTRA_REQUIRES,
    platforms='any',
    classifiers=CLASSIFIERS,
    # namespace_packages=[
    #     "minchin",
    #     "minchin.pelican",
    #     "minchin.pelican.plugins",
    #     "minchin.pelican.plugins.static_comments",
    # ],
    entry_points={
        'console_scripts': {
            ('blogger-comment-export=minchin.pelican.plugins.static_comments.import.blogger_comment_export:main', ),
        },
    },
)
